@@ -27,7 +27,7 @@ class PsmPy:
         List of variables to ignore in regression/matching.
     target : str (optional)
         Outcome variable of interest, will ignore in regression/matching
-    ----------    
+    ----------
     """
 
     def __init__(self, data, treatment, indx, exclude=[], target='outcome'):
@@ -90,12 +90,14 @@ class PsmPy:
                 joint_df = pd.concat([i, minority])
                 treatment = joint_df[self.treatment]
                 df_cleaned = joint_df.drop([self.treatment], axis=1)
+                df_cleaned_cols = df_cleaned.columns
                 # define standard scaler
                 scaler = StandardScaler()
                 df_cleaned = scaler.fit_transform(df_cleaned)
                 logistic = LogisticRegression(solver='liblinear')
                 logistic.fit(df_cleaned, treatment)
                 pscore = logistic.predict_proba(df_cleaned)[:, 1]
+                df_cleaned = pd.DataFrame(df_cleaned, columns=df_cleaned_cols)
                 df_cleaned['propensity_score'] = pscore
                 # df_cleaned['propensity_logit'] = np.array(
                 # logit(xi) for xi in pscore)
@@ -112,27 +114,29 @@ class PsmPy:
                     majority_leftover1 = majority[majority_trunc_len:]
                     # select the ones that have already been processed:
                     majority_already_folded = majority[:majority_trunc_len]
-                    #self.majority_already_folded = majority_already_folded
+                    # self.majority_already_folded = majority_already_folded
                     # sample from the ones already folded over above to get major class of 20 for last fold:
                     majority_leftover2 = majority_already_folded.sample(
-                        n=need_2_sample_more_majorclass)
+                        n = need_2_sample_more_majorclass)
                     # add the leftover to the additional that need to be sampled to get to 20
-                    majority_leftover_all = pd.concat(
+                    majority_leftover_all=pd.concat(
                         [majority_leftover1, majority_leftover2])
                     # sample a macthing 20 from the minor class
-                    minority_sample = minority.sample(n=20)
-                    joint_df = pd.concat(
+                    minority_sample=minority.sample(n = 20)
+                    joint_df=pd.concat(
                         [majority_leftover_all, minority_sample])
-                    treatment = joint_df[self.treatment]
-                    df_cleaned = joint_df.drop([self.treatment], axis=1)
+                    treatment=joint_df[self.treatment]
+                    df_cleaned=joint_df.drop([self.treatment], axis = 1)
+                    df_cleaned_cols = df_cleaned.columns
                     # define standard scaler
-                    scaler = StandardScaler()
-                    df_cleaned = scaler.fit_transform(df_cleaned)
-                    logistic = LogisticRegression(solver='liblinear')
+                    scaler=StandardScaler()
+                    df_cleaned=scaler.fit_transform(df_cleaned)
+                    logistic=LogisticRegression(solver = 'liblinear')
                     logistic.fit(df_cleaned, treatment)
-                    pscore = logistic.predict_proba(df_cleaned)[:, 1]
-                    df_cleaned['propensity_score'] = pscore
-                    df_cleaned['propensity_logit'] = df_cleaned['propensity_score'].apply(
+                    pscore=logistic.predict_proba(df_cleaned)[:, 1]
+                    df_cleaned = pd.DataFrame(df_cleaned, columns=df_cleaned_cols)
+                    df_cleaned['propensity_score']=pscore
+                    df_cleaned['propensity_logit']=df_cleaned['propensity_score'].apply(
                         lambda p: np.log(p/(1-p)))
                     appended_data.append(df_cleaned)
                 else:
@@ -141,12 +145,14 @@ class PsmPy:
                     joint_df = pd.concat([majority_extra, minority_sample])
                     treatment = joint_df[self.treatment]
                     df_cleaned = joint_df.drop([self.treatment], axis=1)
+                    df_cleaned_cols = df_cleaned.columns
                     # define standard scaler
                     scaler = StandardScaler()
                     df_cleaned = scaler.fit_transform(df_cleaned)
                     logistic = LogisticRegression(solver='liblinear')
                     logistic.fit(df_cleaned, treatment)
                     pscore = logistic.predict_proba(df_cleaned)[:, 1]
+                    df_cleaned = pd.DataFrame(df_cleaned, columns=df_cleaned_cols)
                     df_cleaned['propensity_score'] = pscore
                     df_cleaned['propensity_logit'] = df_cleaned['propensity_score'].apply(
                         lambda p: np.log(p/(1-p)))
@@ -167,7 +173,7 @@ class PsmPy:
                     predicted_data_repeated_reset[self.indx] == repeated_id]
                 prop_mean = temp_repeat_df['propensity_score'].mean()
                 prop_logit_mean = logit(prop_mean)
-                short_entry = temp_repeat_df[0:1]
+                short_entry= temp_repeat_df[0: 1]
                 short_entry_rst = short_entry.reset_index(drop=True)
                 short_entry_rst.at[0, 'propensity_score'] = prop_mean
                 short_entry_rst.at[0, 'propensity_logit'] = prop_logit_mean
@@ -176,44 +182,46 @@ class PsmPy:
 
             # remove all duplicated minority class from folded df to be rejoined with the fixed values
             not_repeated_predicted = predicted_data_repeated_reset.drop_duplicates(
-                subset=self.indx, keep=False)
-            predicted_data_ps = pd.concat(
-                [filtered_repeated, not_repeated_predicted]).reset_index(drop=True)
+                subset = self.indx, keep = False)
+            predicted_data_ps=pd.concat(
+                [filtered_repeated, not_repeated_predicted]).reset_index(drop = True)
 
             # merge with treatment df
-            treatment_dfonly = self.dataIDindx[[self.treatment]].reset_index()
-            self.predicted_data = pd.merge(
-                predicted_data_ps, treatment_dfonly, how='inner', on=self.indx)
-            predicted_data_control = self.predicted_data[self.predicted_data[self.treatment] == 0]
-            predicted_data_treatment = self.predicted_data[self.predicted_data[self.treatment] == 1]
+            treatment_dfonly=self.dataIDindx[[self.treatment]].reset_index()
+            self.predicted_data=pd.merge(
+                predicted_data_ps, treatment_dfonly, how = 'inner', on = self.indx)
+            predicted_data_control=self.predicted_data[self.predicted_data[self.treatment] == 0]
+            predicted_data_treatment=self.predicted_data[self.predicted_data[self.treatment] == 1]
 
             # return predicted_data
         # If user does not wish cases to be balanced
         else:
-            joint_df = pd.concat([majority, minority])
-            treatment = joint_df[self.treatment]
-            df_cleaned = joint_df.drop([self.treatment], axis=1)
+            joint_df=pd.concat([majority, minority])
+            treatment=joint_df[self.treatment]
+            df_cleaned=joint_df.drop([self.treatment], axis = 1)
+            df_cleaned_cols = df_cleaned.columns
             # define standard scaler
-            scaler = StandardScaler()
-            df_cleaned = scaler.fit_transform(df_cleaned)
-            logistic = LogisticRegression(solver='liblinear')
+            scaler=StandardScaler()
+            df_cleaned=scaler.fit_transform(df_cleaned)
+            logistic=LogisticRegression(solver = 'liblinear')
             logistic.fit(df_cleaned, treatment)
-            pscore = logistic.predict_proba(df_cleaned)[:, 1]
-            df_cleaned['propensity_score'] = pscore
-            df_cleaned['propensity_logit'] = df_cleaned['propensity_score'].apply(
+            pscore=logistic.predict_proba(df_cleaned)[:, 1]
+            df_cleaned = pd.DataFrame(df_cleaned, columns=df_cleaned_cols)
+            df_cleaned['propensity_score']=pscore
+            df_cleaned['propensity_logit']=df_cleaned['propensity_score'].apply(
                 lambda p: np.log(p/(1-p)))
             predicted_data_reset = df_cleaned.reset_index()
 
             # merge with treatment df
             treatment_dfonly = self.dataIDindx[[self.treatment]].reset_index()
             self.predicted_data = pd.merge(
-                predicted_data_reset, treatment_dfonly, how='inner', on=self.indx)
-            predicted_data_control = self.predicted_data[self.predicted_data[self.treatment] == 0]
-            predicted_data_treatment = self.predicted_data[self.predicted_data[self.treatment] == 1]
+                predicted_data_reset, treatment_dfonly, how = 'inner', on = self.indx)
+            predicted_data_control=self.predicted_data[self.predicted_data[self.treatment] == 0]
+            predicted_data_treatment=self.predicted_data[self.predicted_data[self.treatment] == 1]
 
             # return predicted_data
 
-    def knn_matched(self, matcher, replacement=False, caliper=None):
+    def knn_matched(self, matcher, replacement = False, caliper = None):
         """
         knn_matched -- Match data using k-nn algorithm
         Parameters
@@ -228,9 +236,9 @@ class PsmPy:
         balanced_match : pd.DataFrame
             DataFrame with column with matched ID based on k-NN algorithm
         """
-        matcher = matcher
-        predicted_data_control = self.predicted_data[self.predicted_data[self.treatment] == 0]
-        predicted_data_treatment = self.predicted_data[self.predicted_data[self.treatment] == 1]
+        matcher=matcher
+        predicted_data_control=self.predicted_data[self.predicted_data[self.treatment] == 0]
+        predicted_data_treatment=self.predicted_data[self.predicted_data[self.treatment] == 1]
 
         # if caliper_multip is not None:
         # caliper = np.std(predicted_data_control[matcher]) * caliper_multip
@@ -238,23 +246,23 @@ class PsmPy:
         # pass
 
         if len(predicted_data_treatment) < len(predicted_data_control):
-            min_pred, major_pred = predicted_data_treatment, predicted_data_control
-            major_pred_rstindx = major_pred.reset_index(drop=True)
-            minor_pred_rstindx = min_pred.reset_index(drop=True)
+            min_pred, major_pred=predicted_data_treatment, predicted_data_control
+            major_pred_rstindx=major_pred.reset_index(drop = True)
+            minor_pred_rstindx=min_pred.reset_index(drop = True)
         elif len(predicted_data_treatment) > len(predicted_data_control):
-            min_pred, major_pred = predicted_data_control, predicted_data_treatment
-            major_pred_rstindx = major_pred.reset_index(drop=True)
-            minor_pred_rstindx = min_pred.reset_index(drop=True)
+            min_pred, major_pred=predicted_data_control, predicted_data_treatment
+            major_pred_rstindx=major_pred.reset_index(drop = True)
+            minor_pred_rstindx=min_pred.reset_index(drop = True)
         else:
-            min_pred, major_pred = predicted_data_control, predicted_data_treatment
-            major_pred_rstindx = major_pred.reset_index(drop=True)
-            minor_pred_rstindx = min_pred.reset_index(drop=True)
+            min_pred, major_pred=predicted_data_control, predicted_data_treatment
+            major_pred_rstindx=major_pred.reset_index(drop = True)
+            minor_pred_rstindx=min_pred.reset_index(drop = True)
 
         # need to fit KNN with larger class
-        knn = NearestNeighbors(n_neighbors=len(major_pred_rstindx), p=2)
+        knn=NearestNeighbors(n_neighbors = len(major_pred_rstindx), p = 2)
         knn.fit(major_pred_rstindx[[matcher]].to_numpy())
-        distances, indexes = knn.kneighbors(
-            minor_pred_rstindx[[matcher]], n_neighbors=len(major_pred_rstindx))
+        distances, indexes=knn.kneighbors(
+            minor_pred_rstindx[[matcher]], n_neighbors = len(major_pred_rstindx))
 
         def condition_caliper(x, caliper):
             return x <= caliper
@@ -262,15 +270,15 @@ class PsmPy:
         # remove elements outside of radius:
         if caliper is not None:
             for dist in distances[:, :]:
-                dist = np.ndarray.tolist(dist)
-                self.output_dist_indices = [idx for idx, element in enumerate(
+                dist=np.ndarray.tolist(dist)
+                self.output_dist_indices=[idx for idx, element in enumerate(
                     dist) if condition_caliper(element, caliper)]
             if replacement == False:
-                indexes_for_match = []
-                elements_to_remove = []
+                indexes_for_match=[]
+                elements_to_remove=[]
                 for row in indexes[:, :]:
-                    row = np.ndarray.tolist(row)
-                    row_distclean = [row[index]
+                    row=np.ndarray.tolist(row)
+                    row_distclean=[row[index]
                                      for index in self.output_dist_indices]
                     for element in elements_to_remove:
                         if element in row_distclean:
@@ -279,7 +287,7 @@ class PsmPy:
                     elements_to_remove.append(row_distclean[0])
             else:
                 indexes_for_match = []
-                for row in indexes[:, :]:
+                for row in indexes[: , : ]:
                     row = np.ndarray.tolist(row)
                     row_distclean = [row[index]
                                      for index in self.output_dist_indices]
@@ -289,7 +297,7 @@ class PsmPy:
             if replacement == False:
                 indexes_for_match = []
                 elements_to_remove = []
-                for row in indexes[:, :]:
+                for row in indexes[: , : ]:
                     row = np.ndarray.tolist(row)
                     for element in elements_to_remove:
                         if element in row:
@@ -298,7 +306,7 @@ class PsmPy:
                     elements_to_remove.append(row[0])
             else:
                 indexes_for_match = []
-                for row in indexes[:, :]:
+                for row in indexes[: , : ]:
                     row = np.ndarray.tolist(row)
                     indexes_for_match.append(row[0])
 
@@ -309,11 +317,11 @@ class PsmPy:
 
         major_matched = major_pred_rstindx.take(indexes_for_match)
         self.df_matched = pd.concat(
-            [minor_pred_rstindx, major_matched], axis=0, ignore_index=True)
-        minor_pred_rstindx['matched_ID'] = ID_match
-        self.matched_ids = minor_pred_rstindx[[self.indx, 'matched_ID']]
+            [minor_pred_rstindx, major_matched], axis = 0, ignore_index = True)
+        minor_pred_rstindx['matched_ID']=ID_match
+        self.matched_ids=minor_pred_rstindx[[self.indx, 'matched_ID']]
 
-    def plot_match(self, matched_entity='propensity_logit', Title='Side by side matched controls', Ylabel='Number of patients', Xlabel='propensity logit', names=['treatment', 'control'], colors=['#E69F00', '#56B4E9'], save=False):
+    def plot_match(self, matched_entity = 'propensity_logit', Title = 'Side by side matched controls', Ylabel = 'Number of patients', Xlabel = 'propensity logit', names = ['treatment', 'control'], colors = ['#E69F00', '#56B4E9'], save = False):
         """
         knn_matched -- Match data using k-nn algorithm
         Parameters
@@ -328,35 +336,35 @@ class PsmPy:
         balanced_match : pd.DataFrame
             DataFrame with column with matched ID based on k-NN algorithm
         """
-        dftreat = self.df_matched[self.df_matched[self.treatment] == 1]
-        dfcontrol = self.df_matched[self.df_matched[self.treatment] == 0]
-        x1 = dftreat[matched_entity]
-        x2 = dfcontrol[matched_entity]
+        dftreat=self.df_matched[self.df_matched[self.treatment] == 1]
+        dfcontrol=self.df_matched[self.df_matched[self.treatment] == 0]
+        x1=dftreat[matched_entity]
+        x2=dfcontrol[matched_entity]
         # Assign colors for each airline and the names
-        colors = colors
-        names = names
+        colors=colors
+        names=names
         sns.set_style("white")
         # Make the histogram using a list of lists
         # Normalize the flights and assign colors and names
-        plt.hist([x1, x2], color=colors, label=names)
+        plt.hist([x1, x2], color = colors, label = names)
         # Plot formatting
         plt.legend()
         plt.xlabel(Xlabel)
         plt.ylabel(Ylabel)
         plt.title(Title)
         if save == True:
-            plt.savefig('propensity_match.png', dpi=250)
+            plt.savefig('propensity_match.png', dpi = 250)
         else:
             pass
 
-    def effect_size_plot(self, title='Standardized Mean differences accross covariates before and after matching',
-                         before_color='#FCB754', after_color='#3EC8FB', save=False):
+    def effect_size_plot(self, title = 'Standardized Mean differences accross covariates before and after matching',
+                         before_color = '#FCB754', after_color = '#3EC8FB', save = False):
         """
-        effect_size_plot -- Plot effect size on each variable before and after matching 
+        effect_size_plot -- Plot effect size on each variable before and after matching
         Parameters
         ----------
         title : str (optional)
-           Title the graphic generated 
+           Title the graphic generated
         before_color : str (hex)
            color for the before matching effect size per variable
         after_color : str (hex)
@@ -366,12 +374,12 @@ class PsmPy:
         Returns
         Seaborn graphic
         """
-        df_preds_after = self.df_matched[[self.treatment] + self.xvars]
-        df_preds_b4 = self.data[[self.treatment] + self.xvars]
-        df_preds_after_float = df_preds_after.astype(float)
-        df_preds_b4_float = df_preds_b4.astype(float)
+        df_preds_after=self.df_matched[[self.treatment] + self.xvars]
+        df_preds_b4=self.data[[self.treatment] + self.xvars]
+        df_preds_after_float=df_preds_after.astype(float)
+        df_preds_b4_float=df_preds_b4.astype(float)
 
-        data = []
+        data=[]
         for cl in self.xvars:
             try:
                 data.append([cl, 'before', cohenD(
@@ -383,14 +391,14 @@ class PsmPy:
                     df_preds_after_float, self.treatment, cl)])
             except:
                 data.append([cl, 'after', 0])
-        self.effect_size = pd.DataFrame(
-            data, columns=['Variable', 'matching', 'Effect Size'])
+        self.effect_size=pd.DataFrame(
+            data, columns = ['Variable', 'matching', 'Effect Size'])
         sns.set_style("white")
-        sns_plot = sns.barplot(data=self.effect_size, y='Variable', x='Effect Size', hue='matching', palette=[
-                               before_color, after_color], orient='h')
-        sns_plot.set(title=title)
+        sns_plot=sns.barplot(data = self.effect_size, y = 'Variable', x = 'Effect Size', hue = 'matching', palette = [
+                               before_color, after_color], orient = 'h')
+        sns_plot.set(title = title)
         if save == True:
             sns_plot.figure.savefig(
-                'effect_size.png', dpi=250, bbox_inches="tight")
+                'effect_size.png', dpi = 250, bbox_inches = "tight")
         else:
             pass
